@@ -20,7 +20,7 @@ has missing_after                  => 1800;
 has [qw(remove_after stuck_after)] => 172800;
 has tasks                          => sub { {} };
 
-our $VERSION = '10.16';
+our $VERSION = '10.17';
 
 sub add_task {
   my ($self, $name, $task) = @_;
@@ -217,9 +217,9 @@ Minion - Job queue
 =end html
 
 L<Minion> is a high performance job queue for the Perl programming language, with support for multiple named queues,
-priorities, delayed jobs, job dependencies, job progress, job results, retries with backoff, rate limiting, unique
-jobs, expiring jobs, statistics, distributed workers, parallel processing, autoscaling, remote control,
-L<Mojolicious|https://mojolicious.org> admin ui, resource leak protection and multiple backends (such as
+priorities, high priority fast lane, delayed jobs, job dependencies, job progress, job results, retries with backoff,
+rate limiting, unique jobs, expiring jobs, statistics, distributed workers, parallel processing, autoscaling, remote
+control, L<Mojolicious|https://mojolicious.org> admin ui, resource leak protection and multiple backends (such as
 L<PostgreSQL|https://www.postgresql.org>).
 
 Job queues allow you to process time and/or computationally intensive tasks in background processes, outside of the
